package javax.swing.border;

import java.awt.Insets;
import java.awt.geom.Rectangle2D;
import java.awt.RenderingHints;
import java.awt.Graphics2D;
import java.awt.Graphics;
import java.awt.Component;
import java.beans.ConstructorProperties;
import java.awt.Paint;
import java.awt.BasicStroke;

public class StrokeBorder extends AbstractBorder
{
    private final BasicStroke stroke;
    private final Paint paint;
    
    public StrokeBorder(BasicStroke basicStroke) {
        this(basicStroke, null);
    }
    
    @ConstructorProperties({ "stroke", "paint" })
    public StrokeBorder(BasicStroke stroke, Paint paint) {
        if (stroke == null) {
            throw new NullPointerException("border's stroke");
        }
        this.stroke = stroke;
        this.paint = paint;
        return;
    }
    
    @Override
    public void paintBorder(Component component, Graphics create, int n, int n2, int n3, int n4) {
        float lineWidth = this.stroke.getLineWidth();
        if (lineWidth > 0.0f) {
            create = create.create();
            if ((create instanceof Graphics2D)) {
                Graphics2D graphics2D = (Graphics2D)create;
                graphics2D.setStroke(this.stroke);
                graphics2D.setPaint((this.paint != null) ? this.paint : ((component == null) ? null : component.getForeground()));
                graphics2D.setRenderingHint(RenderingHints.KEY_ANTIALIASING, RenderingHints.VALUE_ANTIALIAS_ON);
                graphics2D.draw(new Rectangle2D.Float((float)n + lineWidth / 2.0f, (float)n2 + lineWidth / 2.0f, (float)n3 - lineWidth, (float)n4 - lineWidth));
            }
            create.dispose();
        }
    }
    
    @Override
    public Insets getBorderInsets(Component component, Insets insets) {
        int n = (int)Math.ceil((double)this.stroke.getLineWidth());
        insets.set(n, n, n, n);
        return insets;
    }
    
    public BasicStroke getStroke() {
        return this.stroke;
    }
    
    public Paint getPaint() {
        return this.paint;
    }
}
